@@ -1517,6 +1517,25 @@ class SuffixesTestCase(HumanNameTestBase):
         self.m(hn.last, "King", hn)
         self.m(hn.suffix, "Jr", hn)
 
+    def test_suffix_with_periods(self):
+        hn = HumanName("John Doe Msc.Ed.")
+        self.m(hn.first,"John", hn)
+        self.m(hn.last,"Doe", hn)
+        self.m(hn.suffix,"Msc.Ed.", hn)
+
+    def test_suffix_with_periods_with_comma(self):
+        hn = HumanName("John Doe, Msc.Ed.")
+        self.m(hn.first,"John", hn)
+        self.m(hn.last,"Doe", hn)
+        self.m(hn.suffix,"Msc.Ed.", hn)
+
+    def test_suffix_with_periods_with_lastname_comma(self):
+        hn = HumanName("Doe, John Msc.Ed.")
+        self.m(hn.first,"John", hn)
+        self.m(hn.last,"Doe", hn)
+        self.m(hn.suffix,"Msc.Ed.", hn)
+
+
 class TitleTestCase(HumanNameTestBase):
 
     def test_last_name_is_also_title(self):
@@ -1719,17 +1738,17 @@ class TitleTestCase(HumanNameTestBase):
         self.m(hn.first, "Jane", hn)
         self.m(hn.last, "Doctor", hn)
 
-    @unittest.expectedFailure
-    def test_title_as_suffix(self):
-        """
-        Semantically, PhD is a title, not a suffix. 
-        http://code.google.com/p/python-nameparser/issues/detail?id=7
-        """
-        hn = HumanName("J. Smith, PhD")
-        self.m(hn.title, "PhD", hn)
-        self.m(hn.first, "J.", hn)
-        self.m(hn.last, "Smith", hn)
+    def test_title_with_periods(self):
+        hn = HumanName("Lt.Gov. John Doe")
+        self.m(hn.title,"Lt.Gov.", hn)
+        self.m(hn.first,"John", hn)
+        self.m(hn.last,"Doe", hn)
 
+    def test_title_with_periods_lastname_comma(self):
+        hn = HumanName("Doe, Lt.Gov. John")
+        self.m(hn.title,"Lt.Gov.", hn)
+        self.m(hn.first,"John", hn)
+        self.m(hn.last,"Doe", hn)
 
 class HumanNameCapitalizationTestCase(HumanNameTestBase):
     def test_capitalization_exception_for_III(self):
@@ -1772,6 +1791,11 @@ class HumanNameCapitalizationTestCase(HumanNameTestBase):
         hn.capitalize()
         self.m(str(hn), 'Shirley Maclaine', hn)
 
+    def test_force_capitalization(self):
+        hn = HumanName('Shirley Maclaine')
+        hn.capitalize(force=True)
+        self.m(str(hn), 'Shirley MacLaine', hn)
+
     def test_capitalize_diacritics(self):
         hn = HumanName('matthëus schmidt')
         hn.capitalize()
